<!--Start of Tawk.to Script-->
{{ tawkto_data|json_script:"tawkto_data" }}
<script type="text/javascript">
  const TawkData = JSON.parse(document.getElementById("tawkto_data").innerText);
  window.Tawk_API = window.Tawk_API || {};
  window.Tawk_LoadStart = new Date();

  if (TawkData.visitor.name || TawkData.visitor.email) {
    window.Tawk_API.visitor = TawkData.visitor;
  }

  if (TawkData.is_secure && TawkData.visitor.email && TawkData.extra_attributes) {
    window.Tawk_API.onLoad = function(){
      window.Tawk_API.setAttributes(TawkData.extra_attributes, function(error){
        if (error) {
          console.log("setAttributes API error", error);
        }
      });
    };
  }

  (function () {
    var s1 = document.createElement("script");
    var s0 = document.getElementsByTagName("script")[0];
    s1.async = true;
    s1.src = TawkData.url;
    s1.charset = "UTF-8";
    s1.setAttribute("crossorigin", "*");
    s0.parentNode.insertBefore(s1, s0);
  })();
</script>
<!--End of Tawk.to Script-->
